@@ -21,6 +21,8 @@
      "fig:Om1astruct"
      "fig:sm2struct"
      "fig:Om2struct"
+     "sec:non-nested"
+     "fig:Sm1struct"
      "sec:role-group-fact"
      "eq:blockDiag"
      "eq:blockblock"
@@ -40,7 +42,31 @@
      "eq:3"
      "sec:singular"
      "sec:reml-estimates"
-     "eq:REMLdev")
+     "eq:REMLdev"
+     "sec:GLMMs"
+     "sec:gener-line-models"
+     "eq:glmlink"
+     "eq:glmlinkinv"
+     "eq:logit"
+     "eq:logitInv"
+     "sec:gener-line-mixed"
+     "eq:glmmLP"
+     "eq:random-effects-dist"
+     "eq:marginalDens"
+     "eq:conditionalmodes"
+     "sec:deta-pirls-algor"
+     "eq:rthLinPred"
+     "eq:adjdep"
+     "eq:IRLSupdate"
+     "eq:conditionalmin"
+     "eq:PIRLSupdate"
+     "eq:PIRLSbstarupdate"
+     "eq:varcov"
+     "sec:deta-lapl-appr"
+     "eq:LaplaceApprox"
+     "app:notation"
+     "sec:randomVariables"
+     "sec:dimensions")
     (TeX-add-symbols
      '("package" 1)
      '("code" 1)
